@@ -32,7 +32,8 @@ namespace KMPlayer {
 
 class Control;
 class ImageData;
-
+class CalculatedSizer;
+class Surface;
 
 /*
  * Class that creates Actor and keeps track objects
@@ -155,7 +156,8 @@ struct KMPLAYER_NO_EXPORT ImageData {
     ImageData( const String & img);
     ~ImageData();
     void setImage (Image *img);
-    void copyImage (Surface *s, int w, int h, cairo_surface_t *similar);
+    void copyImage (Surface *s, int w, int h, cairo_surface_t *similar,
+            unsigned int *penalty, CalculatedSizer *zoom=NULL);
     bool isEmpty () const {
          return !image && !surface; }
 
