@@ -623,11 +623,11 @@ int main (int argc, char* argv[]) {
     gtk_scrolled_window_set_policy (scroll_window,
             GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     app->playlist_view = createTreeView (app);
-    gtk_scrolled_window_add_with_viewport (scroll_window, app->playlist_view);
+    gtk_container_add (GTK_CONTAINER (scroll_window), app->playlist_view);
     app->vsplit_view = GTK_PANED (gtk_vpaned_new ());
     app->isplit_view = gtk_vbox_new (false, 0);
-    gtk_paned_add1 (app->hsplit_view, GTK_WIDGET (scroll_window));
-    gtk_paned_add2 (app->hsplit_view, GTK_WIDGET (app->vsplit_view));
+    gtk_paned_pack1 (app->hsplit_view, GTK_WIDGET (scroll_window), true, false);
+    gtk_paned_pack2 (app->hsplit_view, GTK_WIDGET (app->vsplit_view), true, false);
     app->view_area = gtk_drawing_area_new ();
     _app_setup_window (app->view_area, app);
     g_signal_connect (app->program, "notify::is-topmost",
