@@ -48,7 +48,7 @@ KDE_NO_EXPORT Node::PlayType ASX::Asx::playType () {
     if (cached_ismrl_version != document ()->m_tree_version)
         for (NodePtr e = firstChild (); e; e = e->nextSibling ()) {
             if (e->id == id_node_title)
-                pretty_name = e->innerText ().stripWhiteSpace ();
+                caption = e->innerText ().stripWhiteSpace ();
             else if (e->id == id_node_base)
                 src = getAsxAttribute (convertNode <Element> (e), "href");
         }
@@ -81,7 +81,7 @@ KDE_NO_EXPORT Node::PlayType ASX::Entry::playType () {
         for (NodePtr e = firstChild (); e; e = e->nextSibling ()) {
             switch (e->id) {
             case id_node_title:
-                pretty_name = e->innerText ().stripWhiteSpace ();
+                caption = e->innerText ().stripWhiteSpace ();
                 break;
             case id_node_base:
                 src = getAsxAttribute (convertNode <Element> (e), "href");
@@ -91,8 +91,8 @@ KDE_NO_EXPORT Node::PlayType ASX::Entry::playType () {
                 ref_child_count++;
             }
         }
-        if (ref_child_count == 1 && !pretty_name.isEmpty ())
-            convertNode <ASX::Ref> (ref)->pretty_name = pretty_name;
+        if (ref_child_count == 1 && !caption.isEmpty ())
+            convertNode <ASX::Ref> (ref)->caption = caption;
         cached_ismrl_version = document()->m_tree_version;
     }
     return play_type_none;
@@ -146,7 +146,7 @@ KMPLAYER_NO_EXPORT void ASX::Entry::deactivate () {
 }
 
 KMPLAYER_NO_EXPORT bool ASX::Entry::expose () const {
-    return ref_child_count > 1 && !pretty_name.isEmpty ();
+    return ref_child_count > 1 && !caption.isEmpty ();
 }
 
 //-----------------------------------------------------------------------------
