@@ -330,6 +330,7 @@ void Control::openDocument (NodePtr doc, NodePtr cur) {
         playlist_data->document->document()->dispose ();
     doc->document()->notify_listener = this;
     playlist_data->document = doc;
+    playlist_data->current = cur ? cur : doc;
     cur_url = doc->caption;
     app_set_title ((const char *) cur_url, m_app);
     back_request = cur;
@@ -611,6 +612,7 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
                 (ns > Node::state_deferred &&
                  m_process->state() == Process::Paused))
             m_process->pause ();
+        VIEWAREA(m_app)->setEventFiltering (m_app, true);
         app_set_playing (m_app, ns > Node::state_deferred ? PLAYING : PAUSED);
     } else if (ns == Node::state_activated) {
         if (n == playlist_data->document) {
@@ -633,7 +635,7 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
 }
 
 void Control::updateViewAreaSizes () {
-    if (!VIEWAREA(m_app)->videoWindow () || !m_process)
+    if (!m_process || !VIEWAREA(m_app)->videoWindow ())
         return;
     VIEWAREA(m_app)->resizeEvent();
     Rect video_rect = VIEWAREA(m_app)->videoGeometry ();
@@ -895,6 +897,7 @@ Application *app_new () {
     memset (app, 0, sizeof (Application));
     app->control = new Control (app);
     StringPool::init();
+    app->viewarea = new ViewArea;
     return app;
 }
 
@@ -905,7 +908,6 @@ void app_destroy (Application *app) {
 }
 
 void app_init_control (Application *app) {
-    app->viewarea = new ViewArea;
     CONTROL(app)->init ();
 }
 
