@@ -738,6 +738,17 @@ unsigned int Mrl::parseTimeString (const String &ts) {
     return 0;
 }
 
+String *Mrl::parsePanZoomString (const String &pz, String *coord) {
+    int i;
+    gchar **list = g_strsplit ((const char *) pz, ",", -1);
+    for (i = 0; list [i] && i < 4; ++i)
+        coord[i] = list [i];
+    if (i < 4)
+        warningLog () << "panZoom less then four nubmers" << endl;
+    g_strfreev (list);
+    return i < 4 ? NULL : coord;
+}
+
 //----------------------%<-----------------------------------------------------
 
 void Mrl::parseParam (const TrieString & para, const String & val) {
