@@ -228,12 +228,6 @@ void KMPlayer::updatePlayTree (Application *app) {
         //GdkPixbuf *icon = piter ? iconForNode (e.ptr (), 0) : pld->icon;
         GdkPixbuf *icon = iconForNode (node, 0);
         gtk_tree_store_set (GTK_TREE_STORE (model), &iter, COL_ICON, icon, -1);
-        //gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (app->playlist_view)), &iter);
-        GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
-        gtk_tree_view_expand_to_path (treeview, path);
-        gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
-        gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
-        gtk_tree_path_free (path);
     } else {
         errorLog() << "findNode return false" << endl;
     }
@@ -276,12 +270,9 @@ void KMPlayer::updateTree (Application * app, short id) {
             pld->updated_document == doc &&
             pld->updated_document_version == doc->m_tree_version &&
             gtk_tree_model_get_iter_first (model, &riter )) {
-
         if (pld->current &&
-                findNode (pld, model, pld->current.ptr (), &riter)) {
-            gtk_tree_selection_select_iter (sel, &riter);
+                findNode (pld, model, pld->current.ptr (), &riter))
             fpath = gtk_tree_model_get_path (model, &riter);
-        }
 
     } else {
 
@@ -306,7 +297,7 @@ void KMPlayer::updateTree (Application * app, short id) {
         if (gtk_tree_path_get_depth (fpath) > 1)
             gtk_tree_view_expand_to_path (treeview, fpath);
 
-        gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), fpath);
+        gtk_tree_view_set_cursor (treeview, fpath, NULL, false);
         gtk_tree_view_scroll_to_cell (treeview, fpath, NULL, false, 0, 0);
         gtk_tree_path_free (fpath);
     } else {
@@ -429,53 +420,6 @@ static void restoreEditMode (Application * app, PlayListData * pld) {
         (GTK_WIDGET(app->menu_item_playlist_edit), !!pld->document);
 }
 
-static void activateTopNode (GtkTreeView *tree_view, GtkTreePath *path,
-        PlayListData *pld, NodePtr node, Application *app) {
-    bool need_update = false;
-    GtkTreeModel * model = gtk_tree_view_get_model (tree_view);
-    GtkTreeIter iter;
-    if (node->isPlayable () && !node->active ()) {
-        restoreEditMode (app, pld); // cb_selection_changed is skipped
-        node->activate ();
-        need_update = !node->isPlayable ();
-    } else if (!node->isPlayable ()) {
-        if (pld->updated_document_version !=
-                node->document ()->m_tree_version) {
-            need_update = true;
-        } else {
-            gtk_tree_model_get_iter (model, &iter, path);
-            need_update = !gtk_tree_model_iter_has_child (model, &iter);
-        }
-    }
-    if (need_update) {
-        pld->updated_document = NULL;
-        updateTree (app, pld->id);
-        gtk_tree_model_get_iter (model, &iter, path);
-        if (gtk_tree_model_iter_has_child (model, &iter)) {
-            if (!gtk_tree_view_row_expanded (tree_view, path))
-                gtk_tree_view_expand_row (tree_view, path, FALSE);
-            else
-                gtk_tree_view_collapse_row (tree_view, path);
-        }
-    }
-}
-
-gboolean cb_treeViewClicked (GtkWidget *view, GdkEventButton *evt, Application * app) {
-    GtkTreePath *path;
-    GtkTreeView *tree_view = GTK_TREE_VIEW (view);
-    if (gtk_tree_view_get_path_at_pos (tree_view, (int)evt->x, (int)evt->y,
-                &path, 0l, 0L, 0L)) {
-        PlayListData *pld = getListData (CONTROL(app), path);
-        NodePtr node = getNode (pld, path);
-    debugLog() << "tree clicked" << endl;
-        if (node && gtk_tree_path_get_depth (path) == 1) {
-            activateTopNode (tree_view, path, pld, node, app);
-        }
-        gtk_tree_path_free (path);
-    }
-    return false;
-}
-
 static void setInfoContent (Application *app, Node *node, bool edit_mode) {
     app_set_info_content (app, node
             ? (edit_mode
@@ -484,6 +428,17 @@ static void setInfoContent (Application *app, Node *node, bool edit_mode) {
             : "", edit_mode);
 }
 
+static gboolean delayedUpdateTree (Application *app) {
+    for (PlayListData *pd = CONTROL(app)->playlist_data; pd; pd = pd->next) {
+        if (pd->document &&
+                (!pd->updated_document ||
+                 pd->updated_document_version !=
+                 pd->document->document ()->m_tree_version))
+            updateTree (app, pd->id);
+    }
+    return false;
+}
+
 void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
     if (app->in_tree_update || !selection)
         return;
@@ -501,31 +456,44 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
         NodePtr node = getNode (pld, path);
         Mrl *mrl = node ? node->mrl () : NULL;
         gtk_tree_path_free (path);
-        if (mrl && pld->id > 0 && node == pld->document && !mrl->resolved) {
+        if (mrl && pld->id > 0 && node == pld->document && !mrl->resolved)
             mrl->activate ();
-            if (!node->isPlayable ()) // lazy playlist/recents loading
-                updateTree (app, pld->id);
-        } else {
-            setInfoContent (app, node.ptr (), pld->edit_mode);
-        }
+        if (mrl && pld->updated_document_version !=
+                mrl->document ()->m_tree_version)
+            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+        setInfoContent (app, node.ptr (), pld->edit_mode);
         CONTROL(app)->setCurrentSelected (node);
         if (mrl && pld->id > 0) //FIXME, hack to become less jumpy when changing trees
             pld->current = node;
     }
 }
 
+static gboolean delayedJump (Application *app) {
+    GtkTreePath *path;
+    PlayListData * pld = getListDataFromSelection (app, &path);
+    if (pld) {
+        jump (pld->current.ptr (), CONTROL(app));
+        gtk_tree_path_free (path);
+    }
+    return false;
+}
+
 void cb_row_activated (GtkTreeView * tree_view, GtkTreePath *path,
         GtkTreeViewColumn *arg2, Application * app) {
     PlayListData *pld = getListData (CONTROL(app), path);
     NodePtr node = getNode (pld, path);
     debugLog() << "row activated" << endl;
-    if (gtk_tree_path_get_depth (path) == 1) {
-        activateTopNode (tree_view, path, pld, node, app);
-    } else {
+    if (gtk_tree_path_get_depth (path) != 1) {
         if (pld->id == 0 || pld->edit_mode)
             setInfoContent (app, node.ptr (), pld->edit_mode);
-        if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
-            jump (node.ptr (), CONTROL(app));
+        if (!pld->edit_mode && (pld->id == 0 || (node && node->mrl ()))) {
+            if (pld->id > 0) {
+                pld->current = node;
+                g_idle_add ((GSourceFunc) delayedJump, (gpointer) app);
+            } else {
+                jump (node.ptr (), CONTROL(app));
+            }
+        }
     }
 }
 
@@ -669,6 +637,7 @@ short KMPlayer::addTree (Application * app, NodePtr doc, GdkPixbuf * ico) {
     *prev = new PlayListData (id);
     (*prev)->document = doc;
     (*prev)->icon = ico;
+    (*prev)->updated_document = doc ? doc->document () : NULL;
     const char * title = "empty";
     if (doc && !doc->caption.isEmpty())
         title = (const char *) doc->caption;
@@ -712,6 +681,7 @@ GtkWidget * createTreeView (Application * app) {
     //gtk_tree_view_column_set_title(col, "Title");
 
     app->playlist_cell_renderer = gtk_cell_renderer_pixbuf_new();
+    gtk_cell_renderer_set_fixed_size (app->playlist_cell_renderer, 26, 26);
     gtk_tree_view_column_pack_start(col, app->playlist_cell_renderer, FALSE);
     gtk_tree_view_column_set_attributes(col, app->playlist_cell_renderer,
             "pixbuf", COL_ICON,
@@ -722,9 +692,12 @@ GtkWidget * createTreeView (Application * app) {
     pango_font_description_set_size (pfd, 12);
 
     app->playlist_cell_renderer = gtk_cell_renderer_text_new();
+    gtk_cell_renderer_text_set_fixed_height_from_font (
+            GTK_CELL_RENDERER_TEXT(app->playlist_cell_renderer), 1);
     //g_value_init (&prop_value, G_TYPE_BOOLEAN);
     //g_value_set_boolean (&prop_value, TRUE);
     //g_object_set_property (G_OBJECT (renderer), "editable", &prop_value);
+    GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW (view));
     g_object_set (G_OBJECT (view), "headers-visible", FALSE, 0L);
     g_object_set (G_OBJECT (app->playlist_cell_renderer),
             "font", "Sans 15", 0L);
@@ -738,15 +711,14 @@ GtkWidget * createTreeView (Application * app) {
             "row-expanded", G_CALLBACK (cb_treerow_expanded), app);
     g_signal_connect (G_OBJECT (view),
             "row-activated", G_CALLBACK (cb_row_activated), app);
-    g_signal_connect (G_OBJECT (view),
-            "button-press-event", G_CALLBACK (cb_treeViewClicked), app);
-    g_signal_connect(G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(view))),
+    g_signal_connect(G_OBJECT (sel),
             "changed", G_CALLBACK (cb_selection_changed), app);
     gtk_tree_view_column_set_cell_data_func (col, app->playlist_cell_renderer,
             cb_treeCellDataFunc, app, false);
 
     gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (view), col);
+    gtk_tree_selection_set_mode (sel, GTK_SELECTION_BROWSE);
 
     gtk_widget_show_all(view);
 
@@ -923,11 +895,10 @@ void togglePlaylistShowAll (GtkCheckMenuItem *menuitem, Application * app) {
         pld->show_all = selected;
         pld->updated_document = NULL;
         //gtk_widget_set_sensitive (app->menu_item_playlist_edit, selected);
-        if (pld->edit_mode && !selected) {
+        if (pld->edit_mode && !selected)
             gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_edit), false);
-            // callback called?  //setEditPlaylistMode (app, false);
-        } else
-            updateTree (app, pld->id);
+        else
+            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
     }
 }
 
@@ -961,7 +932,7 @@ void togglePlaylistEdit (GtkCheckMenuItem *menuitem, Application * app) {
         if (!pld->show_all && editable)
             gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_showall), true);
         else
-            updateTree (app, pld->id);
+            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
         NodePtr node = pld->current;
         if (!node)
             node = pld->document;
