@@ -294,29 +294,47 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
         cmdline += String (" -ss ") + String::number (mrl->clip_begin/10);
     cmdline += Char (' ');
 
-    for (NodePtr n = mrl; n; n = n->parentNode ()) {
+    const TrieString aspect_ratio ("aspectRatio");
+    bool found_attr = false;
+    for (NodePtr n = mrl; n && !found_attr; n = n->parentNode ()) {
         if (n->id != id_node_group_node && n->id != id_node_playlist_item)
             break;
-        String asp = convertNode <Element> (n)->getAttribute ("aspectRatio");
-        if (!asp.isNull ()) {
-            int p = asp.indexOf (Char (':'));
-            if (p > 0) {
-                int a = asp.left (p).toInt ();
-                int b = asp.mid (p + 1).toInt ();
-                if (a > 0 && b > 0)
-                    cmdline += String ("-aspect ") +
-                        String::number (a) + Char (':') + String::number (b);
-            } else {
-                float a = (float) asp.toDouble ();
-                if (a > 0.01) {
-                    char buf[32];
-                    snprintf (buf, sizeof (buf), "%0.3f", a);
-                    cmdline += String ("-aspect ") +
-                        String (buf).replace (Char (','), Char ('.'));
+        AttributePtr a = convertNode <Element> (n)->attributes ()->first ();
+        for (; a; a = a->nextSibling ()) {
+            if (aspect_ratio == a->name ()) {
+                String asp = a->value ();
+                if (asp.isEmpty ())
+                    continue;
+                int p = asp.indexOf (Char (':'));
+                if (p > 0) {
+                    int a = asp.left (p).toInt ();
+                    int b = asp.mid (p + 1).toInt ();
+                    if (a > 0 && b > 0)
+                        cmdline += String ("-aspect ") +
+                            String::number (a) + Char (':') + String::number (b);
+                } else {
+                    float a = (float) asp.toDouble ();
+                    if (a > 0.01) {
+                        char buf[32];
+                        snprintf (buf, sizeof (buf), "%0.3f", a);
+                        cmdline += String ("-aspect ") +
+                            String (buf).replace (Char (','), Char ('.'));
+                    }
                 }
+                cmdline += Char (' ');
+                found_attr = true;
+            } else if (a->name () == StringPool::attr_panzoom) {
+                String coord[4];
+                if (Mrl::parsePanZoomString (a->value (), coord)) {
+                    cmdline += String ("-vf crop=") +
+                        String::number (coord[2].toInt()) + Char (':') +
+                        String::number (coord[3].toInt()) + Char (':') +
+                        String::number (coord[0].toInt()) + Char (':') +
+                        String::number (coord[1].toInt());
+                }
+                cmdline += Char (' ');
+                found_attr = true;
             }
-            cmdline += Char (' ');
-            break;
         }
     }
 
@@ -615,7 +633,7 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (GIOChannel * src) {
                                 updateAspects ();
                         }
                     } else {
-                        char * icy = strstr (tok, "ICY Info");
+                        char *icy = strstr (tok, "ICY Info");
                         if (icy) {
                             //debugLog () << "icy found" << endl;
                             char *t = strstr (icy + 8, "StreamTitle=");
@@ -626,6 +644,25 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (GIOChannel * src) {
                                 infoMessage (String (t + 12));
                             }
                             handled = true;
+                        } else {
+                            // Crop: 320 x 200, 0 ; 20
+                            char *crop = strstr (tok, "Crop:");
+                            if (crop) {
+                                char *by = strchr (tok + 5, 'x');
+                                if (by) {
+                                    char *endptr = NULL;
+                                    int w = strtol (tok + 5, &endptr, NULL);
+                                    if (w > 0 && endptr != tok + 5) {
+                                        int h = strtol (by + 1, &endptr, NULL);
+                                        if (h > 0 && endptr != by + 1) {
+                                            m_width = w;
+                                            m_height = h;
+                                            updateAspects ();
+                                            handled = true;
+                                        }
+                                    }
+                                }
+                            }
                         }
                     }
                 }
