@@ -117,21 +117,35 @@ public:
     operator double () const { return 1.0 * value / 256; }
 };
 
+class KMPLAYER_NO_EXPORT SSize {
+public:
+    SSize () {}
+    SSize (Single w, Single h) : width (w), height (h) {}
+
+    bool isEmpty () const { return width <= 0 || height <= 0; }
+    bool operator == (const SSize &s) const;
+    bool operator != (const SSize &s) const;
+
+    Single width, height;
+};
+
 class KMPLAYER_NO_EXPORT SRect {
-    Single _x, _y, _w, _h;
+    Single _x, _y;
 public:
     SRect () {}
     SRect (Single a, Single b, Single w, Single h)
-        : _x (a), _y (b), _w (w), _h (h) {}
+        : _x (a), _y (b), size (w, h) {}
+    SRect (Single a, Single b, const SSize &s) : _x (a), _y (b), size (s) {}
     Single x () const { return _x; }
     Single y () const { return _y; }
-    Single width () const { return _w; }
-    Single height () const { return _h; }
+    Single width () const { return size.width; }
+    Single height () const { return size.height; }
     SRect unite (const SRect & r) const;
     SRect intersect (const SRect & r) const;
-    bool isValid () const { return _w >= Single (0) && _h >= Single (0); }
     bool operator == (const SRect & r) const;
     bool operator != (const SRect & r) const;
+
+    SSize size;
 };
 
 class KMPLAYER_NO_EXPORT IRect {
@@ -427,7 +441,7 @@ public:
 
 
 typedef TextStreamTmpl <GLibTextStream> TextStream;
-
+/*
 template <class T>
 class URLTmpl {
     T m_url;
@@ -448,7 +462,7 @@ public:
     static String decode_string (const String & str);
     bool isLocalFile () const;
 };
-
+*/
 class GnomeVFSUrl {
     GnomeVFSURI * m_vfsurl;
 public:
@@ -459,6 +473,7 @@ public:
     ~GnomeVFSUrl ();
     GnomeVFSUrl & operator = (const String & url);
     GnomeVFSUrl & operator = (const GnomeVFSUrl & url);
+    bool operator == (const GnomeVFSUrl &u) const { return url() == u.url(); }
     String url () const;
     String path () const;
     String protocol () const;
@@ -466,7 +481,8 @@ public:
     bool isLocalFile () const;
 };
 
-typedef URLTmpl <GnomeVFSUrl> URL;
+//typedef URLTmpl <GnomeVFSUrl> URL;
+typedef GnomeVFSUrl URL;
 
 
 template <class T>
@@ -921,8 +937,16 @@ inline Single operator - (const Single s) {
 
 //-----------------------------------------------------------------------------
 
+inline bool SSize::operator == (const SSize &s) const {
+    return width == s.width && height == s.height;
+}
+
+inline bool SSize::operator != (const SSize &s) const { return !(*this == s); }
+
+//-----------------------------------------------------------------------------
+
 inline bool SRect::operator == (const SRect & r) const {
-    return _x == r._x && _y == r._y && _w == r._w && _h == r._h;
+    return _x == r._x && _y == r._y && size == r.size;
 }
 
 inline bool SRect::operator != (const SRect & r) const { return !(*this == r); }
@@ -1470,7 +1494,7 @@ inline String TextStreamTmpl <T>::readLine () {
 }
 
 //-----------------------------------------------------------------------------
-
+/*
 template <class T>
 inline URLTmpl <T>::URLTmpl () {}
 
@@ -1537,7 +1561,7 @@ template <class T>
 inline bool URLTmpl <T>::isLocalFile () const {
     return m_url.isLocalFile ();
 }
-
+*/
 //-----------------------------------------------------------------------------
 
 template <class T>
