@@ -1442,7 +1442,8 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea ()
    m_fullscreen (false),
    m_event_filter_on (false),
    m_updaters_enabled (true),
-   m_controls_overlap (true) {
+   m_controls_overlap (true),
+   m_video_filter (false) {
 }
 
 KDE_NO_CDTOR_EXPORT ViewArea::~ViewArea () {
@@ -1573,12 +1574,28 @@ void ViewArea::setAudioVideoGeometry (const IRect &rect, unsigned int * bg_color
         debugLog() << "ViewArea::setAudioVideoGeometry " << x << "," << y << " "
             << w << "x" << h << endl;
         gdk_window_move_resize (video, x, y, w, h);
-        gdk_window_move_resize (video_input, x, y, w, h);
+        enableVideoInputFilter (m_video_filter);
         gdk_window_set_background (video, (GdkColor *) (GColor &) color);
         gdk_window_clear (video);
     }
 }
 
+void ViewArea::enableVideoInputFilter (bool enable) {
+    int x, y, w, h;
+    m_video_filter = enable;
+    if (enable) {
+        x = m_av_geometry.x ();
+        y = m_av_geometry.y ();
+        w = m_av_geometry.width();
+        h = m_av_geometry.height ();
+    } else {
+        x = y = -100;
+        w = h = 50;
+    }
+    if (video_input)
+        gdk_window_move_resize (video_input, x, y, w, h);
+}
+
 KDE_NO_EXPORT void ViewArea::setAudioVideoNode (NodePtr n) {
     video_node = n;
     m_av_geometry = Rect ();
